==> calamares-settings-solydxk_4.17%2Br13.tar.xz: source/ts/calamares-solydxk_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Bedankt dat u SolydXK hebt gekozen&lt;/h3&gt;&lt;br /&gt;Deze Linuxdistributie is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;veilig en stabiel;&lt;/li&gt;&lt;li&gt;snel en responsief;&lt;/li&gt;&lt;li&gt;desktop-klaar.&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Geniet van deze nieuwe release en dank u voor het kiezen van SolydXK.&lt;br /&gt;&lt;br /&gt;Afhankelijk van uw instellingen duurt de installatie 15-30 minuten.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Op de schouders van reuzen&lt;/h3&gt;&lt;br /&gt;SolydXK is een GNU/Linuxdistributie afgeleid van en compatibel met Debian.&lt;br /&gt;&lt;br /&gt;SolydXK gebruikt de lichtgewicht Xfce-desktop voor SolydX of de zeer configureerbare en mooie KDE-desktop voor SolydK.&lt;br /&gt;&lt;br /&gt;Onze verbeteringen, de snelle ontwikkeltijd en de enorme selectie van softwarepakketten voor Debian maken van SolydXK één van de meest aantrekkelijke computerbesturingssystemen voor thuisgebruikers.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Klaar voor gebruik&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, LibreOffice zijn reeds geïnstalleerd in SolydXK, zodat u meteen aan de slag kunt met de computer en het internet.&lt;br /&gt;&lt;br /&gt;In tegenstelling tot veel andere Linuxdistributies kan SolydXK uw muziek, internet video&apos;s en meer afspelen.&lt;br /&gt;&lt;br /&gt;Een brede verscheidenheid aan software kan worden geïnstalleerd met een klik van de muis.&lt;br /&gt;&lt;br /&gt;SolydXK is compatibel met de meest populaire bestandsformaten zoals docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, en nog veel meer.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Office tools zijn klaar voor gebruik zodra u SolydXK geïnstalleerd heeft&lt;/h3&gt;&lt;br /&gt;LibreOffice, een krachtige office software suite, is reeds geïnstalleerd in SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is gemakkelijk te leren en eenvoudig in gebruik.&lt;br /&gt;&lt;br /&gt;U kunt het gebruiken om brieven, presentaties en spreadsheets, maar ook schema&apos;s en databases te maken.&lt;br /&gt;&lt;br /&gt;LibreOffice maakt gebruik van het standaard OpenDocument-formaat en werkt met documenten uit andere populaire officetoepassingen, waaronder WordPerfect en Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Een alternatief voor populaire besturingssystemen&lt;/h3&gt;&lt;br /&gt;SolydXK is gebruiksvriendelijk, krachtig en makkelijk te configureren.&lt;br /&gt;&lt;br /&gt;SolydXK is veilig en stabiel. In tegenstelling tot andere besturingssystemen, is het niet vatbaar voor computervirussen of spyware, heeft het geen last van schijffragmentatie, en heeft het geen register dat periodieke reiniging vereist.&lt;br /&gt;&lt;br /&gt;SolydXK kan andere besturingssystemen detecteren en zichzelf ernaast installeren. Wanneer u de computer opstart kunt u kiezen welk besturingssysteem u gebruiken wilt.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Veilige updates&lt;/h3&gt;&lt;br /&gt;Sommige besturingssystemen maken het updaten van je systeem moeilijker dan het zou moeten zijn. SolydXK vindt dat upgrades snel en eenvoudig moeten zijn, waarna je direct weer verder kunt werken.&lt;br /&gt;&lt;br /&gt;De Updatemanager is zichtbaar als icoon in uw systeemvak en laat u zien wanneer er updates beschikbaar zijn. U hoeft updates niet toe te passen wanneer dat niet uitkomt. De Updatemanager zal u niet lastigvallen met pop-ups noch op andere manieren.&lt;br /&gt;&lt;br /&gt;Alle bijgewerkte bestanden worden onderhouden en nauw gecontroleerd door vertrouwde ontwikkelaars en beheerders.&lt;br /&gt;&lt;br /&gt;Alle bestanden worden voor uw gebruik opgeslagen in speciaal beveiligde pakketbronnen.&lt;br /&gt;&lt;br /&gt;De beveiligingspakketbron wordt dagelijks gesynchroniseerd.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Een geweldige gemeenschap&lt;/h3&gt;&lt;br /&gt;SolydXK-gebruikers delen onze passie en enthousiasme met plezier en zullen u graag helpen. Aarzel niet vragen te stellen op de forums of zelf bij te dragen in de gemeenschap.&lt;br /&gt;&lt;br /&gt;Geef ons feedback en vertel ons over uw ervaringen. We zullen luisteren naar uw ideeën en ze gebruiken om SolydXK verder te verbeteren.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Bedankt dat u SolydXK hebt gekozen&lt;/h3&gt;&lt;br /&gt;Deze Linuxdistributie is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;veilig en stabiel;&lt;/li&gt;&lt;li&gt;snel en responsief;&lt;/li&gt;&lt;li&gt;desktop-klaar.&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Geniet van deze nieuwe release en dank u voor het kiezen van SolydXK.&lt;br /&gt;&lt;br /&gt;Afhankelijk van uw instellingen duurt de installatie 15-30 minuten.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Op de schouders van reuzen&lt;/h3&gt;&lt;br /&gt;SolydXK is een GNU/Linuxdistributie afgeleid van en compatibel met Debian.&lt;br /&gt;&lt;br /&gt;SolydXK gebruikt de lichtgewicht Xfce-desktop voor SolydX of de zeer configureerbare en mooie KDE-desktop voor SolydK.&lt;br /&gt;&lt;br /&gt;Onze verbeteringen, de snelle ontwikkeltijd en de enorme selectie van softwarepakketten voor Debian maken van SolydXK één van de meest aantrekkelijke computerbesturingssystemen voor thuisgebruikers.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Klaar voor gebruik&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, LibreOffice zijn reeds geïnstalleerd in SolydXK, zodat u meteen aan de slag kunt met de computer en het internet.&lt;br /&gt;&lt;br /&gt;In tegenstelling tot veel andere Linuxdistributies kan SolydXK uw muziek, internet video&apos;s en meer afspelen.&lt;br /&gt;&lt;br /&gt;Een brede verscheidenheid aan software kan worden geïnstalleerd met een klik van de muis.&lt;br /&gt;&lt;br /&gt;SolydXK is compatibel met de meest populaire bestandsformaten zoals docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, en nog veel meer.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Office tools zijn klaar voor gebruik zodra u SolydXK geïnstalleerd heeft&lt;/h3&gt;&lt;br /&gt;LibreOffice, een krachtige office software suite, is reeds geïnstalleerd in SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is gemakkelijk te leren en eenvoudig in gebruik.&lt;br /&gt;&lt;br /&gt;U kunt het gebruiken om brieven, presentaties en spreadsheets, maar ook schema&apos;s en databases te maken.&lt;br /&gt;&lt;br /&gt;LibreOffice maakt gebruik van het standaard OpenDocument-formaat en werkt met documenten uit andere populaire officetoepassingen, waaronder WordPerfect en Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Een alternatief voor populaire besturingssystemen&lt;/h3&gt;&lt;br /&gt;SolydXK is gebruiksvriendelijk, krachtig en makkelijk te configureren.&lt;br /&gt;&lt;br /&gt;SolydXK is veilig en stabiel. In tegenstelling tot andere besturingssystemen, is het niet vatbaar voor computervirussen of spyware, heeft het geen last van schijffragmentatie, en heeft het geen register dat periodieke reiniging vereist.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Veilige updates&lt;/h3&gt;&lt;br /&gt;Sommige besturingssystemen maken het updaten van je systeem moeilijker dan het zou moeten zijn. SolydXK vindt dat upgrades snel en eenvoudig moeten zijn, waarna je direct weer verder kunt werken.&lt;br /&gt;&lt;br /&gt;De Updatemanager is zichtbaar als icoon in uw systeemvak en laat u zien wanneer er updates beschikbaar zijn. U hoeft updates niet toe te passen wanneer dat niet uitkomt. De Updatemanager zal u niet lastigvallen met pop-ups noch op andere manieren.&lt;br /&gt;&lt;br /&gt;Alle bijgewerkte bestanden worden onderhouden en nauw gecontroleerd door vertrouwde ontwikkelaars en beheerders.&lt;br /&gt;&lt;br /&gt;Alle bestanden worden voor uw gebruik opgeslagen in speciaal beveiligde pakketbronnen.&lt;br /&gt;&lt;br /&gt;De beveiligingspakketbron wordt dagelijks gesynchroniseerd.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Een geweldige gemeenschap&lt;/h3&gt;&lt;br /&gt;SolydXK-gebruikers delen onze passie en enthousiasme met plezier en zullen u graag helpen. Aarzel niet vragen te stellen op de forums of zelf bij te dragen in de gemeenschap.&lt;br /&gt;&lt;br /&gt;Geef ons feedback en vertel ons over uw ervaringen. We zullen luisteren naar uw ideeën en ze gebruiken om SolydXK verder te verbeteren.</translation>
    </message>
</context>
</TS>
